@@ -268,8 +268,8 @@ class Xpol(object):
         #alm2cl
         if self.verbose: print( "Alms 2 cl")
         biased = hp.alm2cl( alms1, alms2, lmax=self.lmax) #healpy order (TT,EE,BB,TE,EB,TB)
-        biased = biased[[0,1,2,3,5,4]] #swith TB and EB
         if self.polar:
+            biased = biased[[0,1,2,3,5,4]] #swith TB and EB
             biased21 = hp.alm2cl( alms2, alms1, lmax=self.lmax)
             biased21 = biased21[[0,1,2,3,5,4]] #swith TB and EB
             biased = np.array( np.concatenate( (biased, biased21[[3,4,5]]))) #concatenate with alms2xalms1
@@ -302,7 +302,7 @@ class Xpol(object):
 
     def _debias_spectra(self, binned):
         if self.polar:
-            TT_TT, EE_EE, EE_BB, TE_TE, EB_EB = self.mll_binned_inv
+            TT_TT, EE_EE, EE_BB, TE_TE = self.mll_binned_inv
         else:
             TT_TT = self.mll_binned_inv
 
@@ -323,10 +323,8 @@ class Xpol(object):
         BB = vec[n:]
         TE = np.dot( TE_TE, binned[3])
         TB = np.dot( TE_TE, binned[4])
-#        EB = np.dot( EB_EB, binned[5])
         ET = np.dot( TE_TE, binned[6])
         BT = np.dot( TE_TE, binned[7])
-#        BE = np.dot( EB_EB, binned[8])
 
         out[0*n:1*n, 0*n:1*n] = EE_EE
         out[1*n:2*n, 1*n:2*n] = EE_EE
@@ -372,7 +370,7 @@ class Xpol(object):
 
     def _inv_mll(self, mll_binned):
         if self.polar:
-            TT_TT, EE_EE, EE_BB, TE_TE, EB_EB = mll_binned
+            TT_TT, EE_EE, EE_BB, TE_TE = mll_binned
         else:
             TT_TT = mll_binned
 
@@ -382,7 +380,6 @@ class Xpol(object):
             return TT_TT
         
         TE_TE = np.linalg.inv(TE_TE)
-        EB_EB = np.linalg.inv(EB_EB)
         out = np.zeros( (2*n,2*n) )
         out[0*n:1*n, 0*n:1*n] = EE_EE
         out[1*n:2*n, 1*n:2*n] = EE_EE
@@ -392,11 +389,11 @@ class Xpol(object):
         EE_EE = out[0*n:1*n, 0*n:1*n]
         EE_BB = out[0*n:1*n, 1*n:2*n]
         
-        return TT_TT, EE_EE, EE_BB, TE_TE, EB_EB
+        return TT_TT, EE_EE, EE_BB, TE_TE
 
     def _get_Mll_blocks(self, wl):
         if self.polar:
-            TT_TT, EE_EE, EE_BB, TE_TE, EB_EB, ier = flib.xpol.mll_blocks_pol(self.lmax, wl)
+            TT_TT, EE_EE, EE_BB, TE_TE, ier = flib.xpol.mll_blocks_pol(self.lmax, wl)
         else:
             TT_TT, ier = flib.xpol.mll_blocks(self.lmax, wl)
         if ier > 0:
@@ -408,13 +405,13 @@ class Xpol(object):
             raise RuntimeError(msg)
 
         if self.polar:
-            return TT_TT, EE_EE, EE_BB, TE_TE, EB_EB
+            return TT_TT, EE_EE, EE_BB, TE_TE
         else:
             return TT_TT
 
     def _get_Mbb(self, wl):
         if self.polar:
-            TT_TT, EE_EE, EE_BB, TE_TE, EB_EB = self._get_Mll_blocks( wl)
+            TT_TT, EE_EE, EE_BB, TE_TE = self._get_Mll_blocks( wl)
         else:
             TT_TT = self._get_Mll_blocks( wl)
 
@@ -427,9 +424,8 @@ class Xpol(object):
         EE_EE = self._p @ EE_EE @ self._q
         EE_BB = self._p @ EE_BB @ self._q
         TE_TE = self._p @ TE_TE @ self._q
-        EB_EB = self._p @ EB_EB @ self._q
         
-        return TT_TT, EE_EE, EE_BB, TE_TE, EB_EB
+        return TT_TT, EE_EE, EE_BB, TE_TE
 
 
 
@@ -472,7 +468,7 @@ class Xcov(Xpol):
             wl = hp.anafast(mask**2,lmax=wlmax)
         else:
             wl = hp.anafast(mask**2,map2=mask2**2,lmax=wlmax)
-        self.TT_TT, self.EE_EE, self.EE_BB, self.TE_TE, self.EB_EB = self._get_Mbb( wl)
+        self.TT_TT, self.EE_EE, self.EE_BB, self.TE_TE = self._get_Mbb( wl)
 
 
     def _smooth_cl( self, cl, lcut=0, nsm=2):
@@ -640,7 +636,7 @@ class Xcov(Xpol):
         sclBC = self._smooth_cl( clBC, nsm=nsm)
 
         n = len(self.lbin)
-        TT_TT, EE_EE, EE_BB, TE_TE, EB_EB = self.mll_binned_inv
+        TT_TT, EE_EE, EE_BB, TE_TE = self.mll_binned_inv
         invmll = np.zeros((5*n, 5*n))
         invmll[  0:  n,   0:  n] = TT_TT
         invmll[  n:2*n,   n:2*n] = EE_EE
